@@ -1,9 +1,9 @@
 #
-# $Id: Split.pm,v 0.5 2004/01/08 07:31:12 sts Exp $
+# $Id: Split.pm,v 0.51 2004/01/10 19:31:45 sts Exp $
 
 package Dir::Split;
 
-our $VERSION = '0.5';
+our $VERSION = '0.51';
 
 use 5.6.1;
 use strict 'vars';
@@ -76,7 +76,7 @@ Dir::Split - split files of a directory to subdirectories.
 
  $dir = Dir::Split->new (\%options);
 
- $return = $dir->split;
+ $return = $dir->split();
 
 =head1 DESCRIPTION
 
@@ -365,7 +365,7 @@ sub _sort_files {
     if ($o->{'f_sort'} eq '+' || $o->{'f_sort'} eq '-') {
         # preserve case-sensitive filenames.
         foreach (@Files) {
-            $F_names_case{lc($_)} = $_;
+           $F_names_case{lc($_)} = $_;
         }
         @Files = map lc, @Files;
 
@@ -630,8 +630,9 @@ __DATA__
 sub _traverse {
     my ($o, $dirs_ref, $files_ref) = @_;
 
-    my (@eval, @stack, @dirs, @files);
-    my $depth = 0;
+    my ($count, @dirs, $eval, @eval, @files,
+        $limit, @stack);
+    $count = 0;
 
     $o->_dir_read($o->{'source'}, \@eval);
     @eval =
@@ -640,7 +641,6 @@ sub _traverse {
 
     TRAVERSE:
     while (@eval) {
-        my $eval;
         if (-d $eval[0]) {
             $eval = shift @eval;
             push @dirs, $eval;
@@ -662,8 +662,7 @@ sub _traverse {
         }
 
         unless (@eval) {
-            no warnings;
-            if (++$depth == $traverse_depth) {
+            if (++$count == $traverse_depth) {
                 last TRAVERSE;
             }
             @eval = @stack;
@@ -972,7 +971,7 @@ Removes the directories themselves after the files have been moved. In order to
 this option requires the C<$Dir::Split::traverse_unlink> to be set. Directories will not be
 removed if a traversing depth has been set.
 
-It is B<NOT> recommended to turn on the latter options C<$Dir::Split::traverse_unlink> and
+It is B<not> recommended to turn on the latter options C<$Dir::Split::traverse_unlink> and
 C<$Dir::Split::traverse_rmdir>, unless you're aware of the consequences they imply.
 
 =head1 EXAMPLES
